/*
 * Code: Ben Walding
 * Date: 1 January 1998
 * 
 * Contains code to display the splash screen on startup.
 *
 * Protected by the GNU Public License v2.0  <distrib>/GPL.LICENSE
 */


#include "splash.h"
#include <qmsgbox.h>
#include <qlabel.h>
#include <qpainter.h>
#include <qkeycode.h>
#include <qapp.h>
#include "splash.moc"


/* XPMS */
#include "xpm/cdlabel.xpm"
#include "xpm/cdlabel_pro.xpm"
#include "xpm/cdlabel_name.xpm"


Splash::Splash( QWidget *parent, const char *name ) : QWidget( parent, name, WType_Modal)
{
  xpmtitle = new QPixmap((const char **) &cdlabel);
  xpmtitlepro = new QPixmap((const char **) &cdlabel_pro);
  xpmtitlename = new QPixmap((const char **) &cdlabel_name);

  setBackgroundColor(black);
  //Hide splash screen after 15 seconds XXX XXX XXX need to undo this for about? What did I just say?
  QTimer::singleShot( 15 * 1000, this, SLOT(undisplay()) );   
}


/*
 * Draws the portion of the scaled pixmap that needs to be updated or prints
 * an error message if no legal pixmap has been loaded.
 */
void Splash::paintEvent( QPaintEvent *e )
{
	QPainter painter(this);
	painter.setClipRect(e->rect());
	painter.drawPixmap((width() - (xpmtitle->width() + xpmtitlepro->width())) / 2, 
					   xpmtitlepro->height() / 2 + 50, *xpmtitle);
	painter.drawPixmap((width() + xpmtitle->width()) / 2 - 20, 50, *xpmtitlepro);
	painter.drawPixmap((width() - xpmtitlename->width()) / 2, height() / 2 + 20, *xpmtitlename);
}

void Splash::mousePressEvent(QMouseEvent *)
{
  undisplay();
}

void Splash::undisplay() {
  delete this;
}




